@@ -114,13 +114,13 @@ void Account::post(const QUrl &url, const QJsonDocument &doc, bool authenticated
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/json");
 
     if (authenticated && haveToken()) {
-        QByteArray bearer = QString("Bearer " + m_token).toLocal8Bit();
+        const QByteArray bearer = QString("Bearer " + m_token).toLocal8Bit();
         request.setRawHeader("Authorization", bearer);
     }
 
     qDebug() << "POST" << url << "[" << post_data << "]";
 
-    QNetworkReply *reply = m_qnam->post(request, post_data);
+    auto reply = m_qnam->post(request, post_data);
 
     if (reply_cb != nullptr) {
         QObject::connect(reply, &QNetworkReply::finished, [reply, reply_cb]() {
@@ -166,7 +166,7 @@ void Account::post(const QUrl &url, const QUrlQuery &formdata, bool authenticate
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
 
     if (authenticated && haveToken()) {
-        QByteArray bearer = QString("Bearer " + m_token).toLocal8Bit();
+        const QByteArray bearer = QString("Bearer " + m_token).toLocal8Bit();
         request.setRawHeader("Authorization", bearer);
     }
 
@@ -191,7 +191,7 @@ void Account::post(const QUrl &url, QHttpMultiPart *message, bool authenticated,
     qDebug() << "POST" << url << "(multipart-message)";
 
     if (authenticated && haveToken()) {
-        QByteArray bearer = QString("Bearer " + m_token).toLocal8Bit();
+        const QByteArray bearer = QString("Bearer " + m_token).toLocal8Bit();
         request.setRawHeader("Authorization", bearer);
     }
 
@@ -226,18 +226,11 @@ void Account::upload(Post *p, QFile *file, QString filename)
         const auto data = reply->readAll();
         const auto doc = QJsonDocument::fromJson(data);
 
-        if (doc.isObject())
+        if (!doc.isObject()) {
             return;
+        }
 
-        auto obj = doc.object();
-
-        auto att = new Attachment(p, obj);
-        if (att->m_url.isEmpty())
-            return;
-
-        p->m_attachments.append(att);
-
-        Q_EMIT attachmentUploaded(p, att);
+        p->addAttachment(doc.object());
     });
 }
 
@@ -397,7 +390,7 @@ void Account::buildFromSettings(const QSettings &settings)
 
 void Account::fetchAccount(int id, bool excludeReplies, std::function<void(QList<std::shared_ptr<Post>>)> final_cb)
 {
-    QList<std::shared_ptr<Post>> *thread = new QList<std::shared_ptr<Post>>;
+    auto thread = std::make_shared<QList<std::shared_ptr<Post>>>();
 
     QUrl uriStatus(m_instance_uri);
     uriStatus.setPath(QString("/api/v1/accounts/%1/statuses").arg(id));
@@ -410,15 +403,16 @@ void Account::fetchAccount(int id, bool excludeReplies, std::function<void(QList
     uriPinned.setQuery(QUrlQuery{{"pinned", "true"}});
 
     auto onFetchPinned = [=](QNetworkReply *reply) {
-        QList<std::shared_ptr<Post>> posts;
         const auto data = reply->readAll();
         const auto doc = QJsonDocument::fromJson(data);
 
         if (!doc.isArray()) {
             return;
         }
+
         int i = 0;
-        for (const auto &value : doc.array()) {
+        const auto array = doc.array();
+        for (const auto &value : array) {
             const QJsonObject obj = value.toObject();
 
             auto p = std::make_shared<Post>(this, obj);
@@ -426,14 +420,10 @@ void Account::fetchAccount(int id, bool excludeReplies, std::function<void(QList
             i++;
         }
 
-        QList<std::shared_ptr<Post>> finalThread = QList<std::shared_ptr<Post>>(*thread);
-        delete thread;
-        final_cb(finalThread);
+        final_cb(*thread);
     };
 
     auto onFetchAccount = [=](QNetworkReply *reply) {
-        QList<std::shared_ptr<Post>> posts;
-
         const auto data = reply->readAll();
         const auto doc = QJsonDocument::fromJson(data);
 
@@ -441,7 +431,8 @@ void Account::fetchAccount(int id, bool excludeReplies, std::function<void(QList
             return;
         }
 
-        for (const auto &value : doc.array()) {
+        const auto array = doc.array();
+        for (const auto &value : array) {
             const QJsonObject obj = value.toObject();
 
             auto p = std::make_shared<Post>(this, obj);
@@ -486,7 +477,8 @@ void Account::fetchTimeline(const QString &original_name, const QString &from_id
             return;
         }
 
-        for (const auto &value : doc.array()) {
+        const auto array = doc.array();
+        for (const auto &value : array) {
             QJsonObject obj = value.toObject();
 
             const auto p = std::make_shared<Post>(this, obj);
@@ -501,7 +493,7 @@ void Account::fetchThread(const QString &post_id, std::function<void(QList<std::
 {
     auto status_url = apiUrl(QString("/api/v1/statuses/%1").arg(post_id));
     auto context_url = apiUrl(QString("/api/v1/statuses/%1/context").arg(post_id));
-    QList<std::shared_ptr<Post>> *thread = new QList<std::shared_ptr<Post>>;
+    auto thread = std::make_shared<QList<std::shared_ptr<Post>>>();
 
     auto on_fetch_context = [=](QNetworkReply *reply) {
         auto data = reply->readAll();
@@ -535,10 +527,7 @@ void Account::fetchThread(const QString &post_id, std::function<void(QList<std::
             thread->push_back(p);
         }
 
-        QList<std::shared_ptr<Post>> finalThread = QList<std::shared_ptr<Post>>(*thread);
-
-        delete thread;
-        final_cb(finalThread);
+        final_cb(*thread);
     };
 
     auto on_fetch_status = [=](QNetworkReply *reply) {
@@ -580,8 +569,6 @@ void Account::mutatePost(std::shared_ptr<Post> p, const QString &verb, bool deli
         auto data = reply->readAll();
         auto doc = QJsonDocument::fromJson(data);
 
-        auto post_id = doc.object()["id"].toString();
-
         if (deliver_home) {
             QList<std::shared_ptr<Post>> posts;
             auto obj = doc.object();
@@ -730,7 +717,7 @@ QWebSocket *Account::streamingSocket(const QString &stream)
 
     auto url = streamingUrl(stream);
 
-    QObject::connect(socket, &QWebSocket::textMessageReceived, [=](const QString &message) {
+    QObject::connect(socket, &QWebSocket::textMessageReceived, this, [=](const QString &message) {
         QString target_tl = stream;
         auto env = QJsonDocument::fromJson(message.toLocal8Bit());
 
