@@ -28,16 +28,17 @@ void AttachmentEditorModel::setPost(Post *post)
     m_scratch = post;
     endResetModel();
     if (m_scratch) {
-        connect(m_scratch->m_parent, &Account::attachmentUploaded, this, [=](Post *p, Attachment *att) {
-            if (p == m_scratch) {
-                // TODO beginInsertModel
-                beginResetModel();
-                endResetModel();
-            }
+        connect(m_scratch, &Post::attachmentUploaded, this, [this] {
+            qDebug() << "Uploaded 2";
+            // TODO beginInsertModel
+            beginResetModel();
+            endResetModel();
+            Q_EMIT countChanged();
         });
     }
 
     Q_EMIT postChanged();
+    Q_EMIT countChanged();
 }
 
 int AttachmentEditorModel::rowCount(const QModelIndex &) const
@@ -48,6 +49,14 @@ int AttachmentEditorModel::rowCount(const QModelIndex &) const
     return m_scratch->m_attachments.size();
 }
 
+int AttachmentEditorModel::count() const
+{
+    if (!m_scratch) {
+        return 0;
+    }
+    return m_scratch->m_attachments.size();
+}
+
 QVariant AttachmentEditorModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid()) {
